Module actor_cell

Module actor_cell 

Module with the internals of Actors.

Structs

ActorCell
Main interface for interractiong with an Actor for the internals.
Failure
Structurer containing Actor Failure informations.

Enums

ControlMessage
Control Messages.
InnerMessage
Types of message that can be sent to an actor that will be treated normally.
SystemMessage
Special messages issued by the actor system. Note that these are treated with the highest priority and will thus be handled before any InnerMessage is handled.

Traits

ActorContext
This is the API that Actors are supposed to see of their context while handling a message.

Type Aliases

FailureHandler
Closure to handle failure of an Actor.