pub enum SystemMessage {
Restart,
Start,
}Expand description
Special messages issued by the actor system. Note that these are treated with the highest priority and will thus be handled before any InnerMessage is handled.
Variants
Restart
Restarts the actor by replacing it with a new version created with its ActorFactory.
Start
Tells the actor to initialize itself. Note that the initialization is not done by the father for fairness reasons.