Module with the internals of Actors.
Structs
- Actor
Cell - Main interface for interractiong with an Actor for the internals.
- Failure
- Structurer containing Actor Failure informations.
Enums
- Control
Message - Control Messages.
- Inner
Message - Types of message that can be sent to an actor that will be treated normally.
- System
Message - Special messages issued by the actor system. Note that these are treated with the highest priority and will thus be handled before any InnerMessage is handled.
Traits
- Actor
Context - This is the API that Actors are supposed to see of their context while handling a message.
Type Aliases
- Failure
Handler - Closure to handle failure of an Actor.