ActorCell

Struct ActorCell 

pub struct ActorCell { /* private fields */ }
Main interface for interractiong with an Actor for the internals.

Implementations

Source

impl ActorCell

pub fn new( props: Arc<dyn ActorFactory>, system: ActorSystem, father: ActorRef, path: Arc<ActorPath>, ) -> ActorCell

Creates a new ActorCell.

pub fn receive_message(&self, message: InnerMessage, sender: ActorRef)

Puts a message with its sender in the Actor’s mailbox and schedules the Actor.

pub fn receive_system_message(&self, system_message: SystemMessage)

Puts a system message with its sender in the Actor’s system mailbox and schedules the Actor.

pub fn handle_envelope(&self)

Makes the Actor handle an envelope in its mailbox.